import { KeyType } from './KeyType';
export type JwkCurve = 'Ed25519' | 'X25519' | 'P-256' | 'P-384' | 'P-521' | 'Bls12381G1' | 'Bls12381G2';
export interface Jwk {
    kty: 'EC' | 'OKP';
    crv: JwkCurve;
    x: string;
    y?: string;
    use?: 'sig' | 'enc';
}
export interface Ed25519JwkPublicKey extends Jwk {
    kty: 'OKP';
    crv: 'Ed25519';
    x: string;
    y?: never;
    use?: 'sig';
}
export interface X25519JwkPublicKey extends Jwk {
    kty: 'OKP';
    crv: 'X25519';
    x: string;
    y?: never;
    use?: 'enc';
}
export interface P256JwkPublicKey extends Jwk {
    kty: 'EC';
    crv: 'P-256';
    x: string;
    y: string;
    use?: 'sig' | 'enc';
}
export interface P384JwkPublicKey extends Jwk {
    kty: 'EC';
    crv: 'P-384';
    x: string;
    y: string;
    use?: 'sig' | 'enc';
}
export interface P521JwkPublicKey extends Jwk {
    kty: 'EC';
    crv: 'P-521';
    x: string;
    y: string;
    use?: 'sig' | 'enc';
}
export declare function isEd25519JwkPublicKey(jwk: Jwk): jwk is Ed25519JwkPublicKey;
export declare function isX25519JwkPublicKey(jwk: Jwk): jwk is X25519JwkPublicKey;
export declare function isP256JwkPublicKey(jwk: Jwk): jwk is P256JwkPublicKey;
export declare function isP384JwkPublicKey(jwk: Jwk): jwk is P384JwkPublicKey;
export declare function isP521JwkPublicKey(jwk: Jwk): jwk is P521JwkPublicKey;
export declare const jwkCurveToKeyTypeMapping: {
    readonly Ed25519: KeyType.Ed25519;
    readonly X25519: KeyType.X25519;
    readonly 'P-256': KeyType.P256;
    readonly 'P-384': KeyType.P384;
    readonly 'P-521': KeyType.P521;
    readonly Bls12381G1: KeyType.Bls12381g1;
    readonly Bls12381G2: KeyType.Bls12381g2;
};
export declare const keyTypeToJwkCurveMapping: {
    readonly ed25519: "Ed25519";
    readonly x25519: "X25519";
    readonly p256: "P-256";
    readonly p384: "P-384";
    readonly p521: "P-521";
    readonly bls12381g1: "Bls12381G1";
    readonly bls12381g2: "Bls12381G2";
};
export declare function isSigningSupportedForKeyType(keyType: KeyType): boolean;
export declare function isEncryptionSupportedForKeyType(keyType: KeyType): boolean;
