"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isEncryptionSupportedForKeyType = exports.isSigningSupportedForKeyType = exports.keyTypeToJwkCurveMapping = exports.jwkCurveToKeyTypeMapping = exports.isP521JwkPublicKey = exports.isP384JwkPublicKey = exports.isP256JwkPublicKey = exports.isX25519JwkPublicKey = exports.isEd25519JwkPublicKey = void 0;
const KeyType_1 = require("./KeyType");
function isEd25519JwkPublicKey(jwk) {
    return jwk.kty === 'OKP' && jwk.crv === 'Ed25519' && jwk.x !== undefined && (!jwk.use || jwk.use === 'sig');
}
exports.isEd25519JwkPublicKey = isEd25519JwkPublicKey;
function isX25519JwkPublicKey(jwk) {
    return jwk.kty === 'OKP' && jwk.crv === 'X25519' && jwk.x !== undefined && (!jwk.use || jwk.use === 'enc');
}
exports.isX25519JwkPublicKey = isX25519JwkPublicKey;
function isP256JwkPublicKey(jwk) {
    return (jwk.kty === 'EC' &&
        jwk.crv === 'P-256' &&
        jwk.x !== undefined &&
        jwk.y !== undefined &&
        (!jwk.use || ['sig', 'enc'].includes(jwk.use)));
}
exports.isP256JwkPublicKey = isP256JwkPublicKey;
function isP384JwkPublicKey(jwk) {
    return (jwk.kty === 'EC' &&
        jwk.crv === 'P-384' &&
        jwk.x !== undefined &&
        jwk.y !== undefined &&
        (!jwk.use || ['sig', 'enc'].includes(jwk.use)));
}
exports.isP384JwkPublicKey = isP384JwkPublicKey;
function isP521JwkPublicKey(jwk) {
    return (jwk.kty === 'EC' &&
        jwk.crv === 'P-521' &&
        jwk.x !== undefined &&
        jwk.y !== undefined &&
        (!jwk.use || ['sig', 'enc'].includes(jwk.use)));
}
exports.isP521JwkPublicKey = isP521JwkPublicKey;
exports.jwkCurveToKeyTypeMapping = {
    Ed25519: KeyType_1.KeyType.Ed25519,
    X25519: KeyType_1.KeyType.X25519,
    'P-256': KeyType_1.KeyType.P256,
    'P-384': KeyType_1.KeyType.P384,
    'P-521': KeyType_1.KeyType.P521,
    Bls12381G1: KeyType_1.KeyType.Bls12381g1,
    Bls12381G2: KeyType_1.KeyType.Bls12381g2,
};
exports.keyTypeToJwkCurveMapping = {
    [KeyType_1.KeyType.Ed25519]: 'Ed25519',
    [KeyType_1.KeyType.X25519]: 'X25519',
    [KeyType_1.KeyType.P256]: 'P-256',
    [KeyType_1.KeyType.P384]: 'P-384',
    [KeyType_1.KeyType.P521]: 'P-521',
    [KeyType_1.KeyType.Bls12381g1]: 'Bls12381G1',
    [KeyType_1.KeyType.Bls12381g2]: 'Bls12381G2',
};
const keyTypeSigningSupportedMapping = {
    [KeyType_1.KeyType.Ed25519]: true,
    [KeyType_1.KeyType.X25519]: false,
    [KeyType_1.KeyType.P256]: true,
    [KeyType_1.KeyType.P384]: true,
    [KeyType_1.KeyType.P521]: true,
    [KeyType_1.KeyType.Bls12381g1]: true,
    [KeyType_1.KeyType.Bls12381g2]: true,
    [KeyType_1.KeyType.Bls12381g1g2]: true,
};
const keyTypeEncryptionSupportedMapping = {
    [KeyType_1.KeyType.Ed25519]: false,
    [KeyType_1.KeyType.X25519]: true,
    [KeyType_1.KeyType.P256]: true,
    [KeyType_1.KeyType.P384]: true,
    [KeyType_1.KeyType.P521]: true,
    [KeyType_1.KeyType.Bls12381g1]: false,
    [KeyType_1.KeyType.Bls12381g2]: false,
    [KeyType_1.KeyType.Bls12381g1g2]: false,
};
function isSigningSupportedForKeyType(keyType) {
    return keyTypeSigningSupportedMapping[keyType];
}
exports.isSigningSupportedForKeyType = isSigningSupportedForKeyType;
function isEncryptionSupportedForKeyType(keyType) {
    return keyTypeEncryptionSupportedMapping[keyType];
}
exports.isEncryptionSupportedForKeyType = isEncryptionSupportedForKeyType;
//# sourceMappingURL=JwkTypes.js.map