"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidPrivateKey = exports.isValidSeed = void 0;
const utils_1 = require("../utils");
const KeyType_1 = require("./KeyType");
function isValidSeed(seed, keyType) {
    const minimumSeedLength = {
        [KeyType_1.KeyType.Ed25519]: 32,
        [KeyType_1.KeyType.X25519]: 32,
        [KeyType_1.KeyType.Bls12381g1]: 32,
        [KeyType_1.KeyType.Bls12381g2]: 32,
        [KeyType_1.KeyType.Bls12381g1g2]: 32,
        [KeyType_1.KeyType.P256]: 64,
        [KeyType_1.KeyType.P384]: 64,
        [KeyType_1.KeyType.P521]: 64,
    };
    return utils_1.Buffer.isBuffer(seed) && seed.length >= minimumSeedLength[keyType];
}
exports.isValidSeed = isValidSeed;
function isValidPrivateKey(privateKey, keyType) {
    const privateKeyLength = {
        [KeyType_1.KeyType.Ed25519]: 32,
        [KeyType_1.KeyType.X25519]: 32,
        [KeyType_1.KeyType.Bls12381g1]: 32,
        [KeyType_1.KeyType.Bls12381g2]: 32,
        [KeyType_1.KeyType.Bls12381g1g2]: 32,
        [KeyType_1.KeyType.P256]: 32,
        [KeyType_1.KeyType.P384]: 48,
        [KeyType_1.KeyType.P521]: 66,
    };
    return utils_1.Buffer.isBuffer(privateKey) && privateKey.length === privateKeyLength[keyType];
}
exports.isValidPrivateKey = isValidPrivateKey;
//# sourceMappingURL=keyUtils.js.map