"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DidJwk = void 0;
const Key_1 = require("../../../../crypto/Key");
const utils_1 = require("../../../../utils");
const parse_1 = require("../../domain/parse");
const didJwkDidDocument_1 = require("./didJwkDidDocument");
class DidJwk {
    constructor(did) {
        this.did = did;
    }
    get allowsEncrypting() {
        return this.jwk.use === 'enc' || this.key.supportsEncrypting;
    }
    get allowsSigning() {
        return this.jwk.use === 'sig' || this.key.supportsSigning;
    }
    static fromDid(did) {
        // We create a `Key` instance form the jwk, as that validates the jwk
        const parsed = (0, parse_1.parseDid)(did);
        const jwk = utils_1.JsonEncoder.fromBase64(parsed.id);
        Key_1.Key.fromJwk(jwk);
        return new DidJwk(did);
    }
    static fromJwk(jwk) {
        // We create a `Key` instance form the jwk, as that validates the jwk
        Key_1.Key.fromJwk(jwk);
        const did = `did:jwk:${utils_1.JsonEncoder.toBase64URL(jwk)}`;
        return new DidJwk(did);
    }
    get key() {
        return Key_1.Key.fromJwk(this.jwk);
    }
    get jwk() {
        const parsed = (0, parse_1.parseDid)(this.did);
        const jwk = utils_1.JsonEncoder.fromBase64(parsed.id);
        return jwk;
    }
    get didDocument() {
        return (0, didJwkDidDocument_1.getDidJwkDocument)(this);
    }
}
exports.DidJwk = DidJwk;
//# sourceMappingURL=DidJwk.js.map